@@ -47,6 +47,7 @@ panel.pairs <-
              panel.subscripts,
              subscripts,
              pscales = 5,
+             panel.number = 0,  ## should always be supplied
              ...)
 {
     panel <- 
@@ -220,14 +221,23 @@ panel.pairs <-
                 }
                 else
                 {
-                    if(!panel.subscripts)
-                        panel(x=as.numeric(z[subscripts, j]),
-                              y=as.numeric(z[subscripts, i]), ...)
+                    pargs <-
+                        if (!panel.subscripts)
+                            c(list(x = as.numeric(z[subscripts, j]),
+                                   y = as.numeric(z[subscripts, i]),
+                                   panel.number = panel.number),
+                              list(...))
+                        else
+                            c(list(x = as.numeric(z[subscripts, j]),
+                                   y = as.numeric(z[subscripts, i]),
+                                   groups = groups,
+                                   subscripts = subscripts,
+                                   panel.number = panel.number),
+                              list(...))
 
-                    else panel(x=as.numeric(z[subscripts, j]),
-                               y=as.numeric(z[subscripts, i]),
-                               groups = groups,
-                               subscripts = subscripts, ...)
+                    if (!("..." %in% names(formals(panel))))
+                        pargs <- pargs[names(formals(panel))]
+                    do.call("panel", pargs)
 
                     grid.rect()
                 }
@@ -300,7 +310,6 @@ splom <-
 
     number.of.cond <- length(cond)
     x <- as.data.frame(form$right)
-
     if (number.of.cond == 0) {
         strip <- FALSE
         cond <- list(as.factor(rep(1, nrow(x))))
@@ -315,7 +324,7 @@ splom <-
     subscr <- seq(along=x[,1])
     x <- x[subset,, drop = TRUE]
     subscr <- subscr[subset, drop = TRUE]
-
+    
 
     ## create a skeleton trellis object with the
     ## less complicated components:
@@ -366,7 +375,7 @@ splom <-
     have.ylim <- !missing(ylim)
     if (!is.null(foo$y.scales$limit)) {
         have.ylim <- TRUE
-        ylim <- foo$x.scales$limit
+        ylim <- foo$y.scales$limit
     }
     if (have.xlim || have.ylim) {
         warning("Limits cannot be explicitly specified")
@@ -481,7 +490,9 @@ splom <-
                                panel.args.common = foo$panel.args.common,
                                panel.args = foo$panel.args,
                                aspect = aspect,
-                               nplots = nplots))
+                               nplots = nplots,
+                               x.axs = foo$x.scales$axs,
+                               y.axs = foo$y.scales$axs))
 
     class(foo) <- "trellis"
     foo
